<template>
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="检查项目" prop="">
        {{formData.checkType && checkTypeStore.getCheckTypeName(formData.checkType)}}
      </el-form-item>
      <el-row :gutter="20">
        <el-col :span="12">
          <el-form-item label="患者编号" prop="patId">
            <el-input v-model="formData.patId" placeholder="请输入患者编号" @input="getRentInfoByPatId" />
<!--        <Qrcode v-if="formData.patId !== undefined && formData.patId !== ''" :text="formData.patId" logo="/logo.gif" width=100 />-->
            <Barcode v-if="getDisplayBarcode()" :value="getDisplayBarcode()" :width=100 />
          </el-form-item>
          <el-form-item label="患者名称" prop="patName">
            <el-input v-model="formData.patName" placeholder="请输入患者名称" />
          </el-form-item>
          <el-form-item label="患者描述" prop="patDeptDesc">
            <dict-tag :type="DICT_TYPE.ECG_PAT_SOURCE" :value="formData.patSrc" />
            {{formData.patDetails?.deptDesc}} {{formData.patDetails?.wardDesc}} {{formData.patDetails?.bedNo}}
          </el-form-item>
          <el-form-item label="装机时间" prop="rentTime">
            <el-date-picker
                v-model="formData.rentTime"
                type="date"
                value-format="x"
                placeholder="选择装机时间"
            />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="设备编号" prop="devId">
            <el-input v-model="formData.devId" placeholder="请输入设备编号" @input="getDevInfo"/>
          </el-form-item>
          <el-form-item label="设备描述" prop="">
            <span v-if="formData.brand !== null"> {{formData.brand}} </span>
             {{"&nbsp;&nbsp;"}}
            <span v-if="formData.model !== null"> {{formData.model}} </span>
          </el-form-item>
          <el-form-item label="备注" prop="remark">
            <el-input v-model="formData.remark" placeholder="请输入备注" />
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <el-button @click="submitForm" type="primary" :disabled="formLoading">装机完成</el-button>
    <el-button @click="resetForm()">重 置</el-button>
    <el-button @click="cancelInstall"  :disabled="formLoading">放弃装机</el-button>

  <!-- 医生装机列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="list" :stripe="true" :show-overflow-tooltip="true" @row-click="onRowClick" >
      <el-table-column label="id" align="center" prop="id" />
      <el-table-column label="装机情况" align="center" prop="lost" >
        <template #default="scope">
          <span v-if="scope.row.jobType === 10">"已装机"</span>
          <span v-if="scope.row.jobType === 35">"已放弃"</span>
        </template>
      </el-table-column>
<!--      <el-table-column label="作业类型" align="center" prop="jobType" />-->
<!--      <el-table-column label="医生编号" align="center" prop="docId" />-->
      <el-table-column label="医生名称" align="center" prop="docName" />
      <el-table-column label="设备编号" align="center" prop="devId" />
      <el-table-column label="患者编号" align="center" prop="patId" />
      <el-table-column label="患者名称" align="center" prop="patName" />
      <el-table-column
          label="作业时间"
          align="center"
          prop="jobTime"
          :formatter="dateFormatter"
          width="180px"
      />
      <el-table-column label="作业概要" align="center" prop="summary" />
      <el-table-column label="备注" align="center" prop="remark" />
      <el-table-column
          label="创建时间"
          align="center"
          prop="createTime"
          :formatter="dateFormatter"
          width="180px"
      />
      <el-table-column label="操作" align="center" min-width="120px">
        <template #default="scope">
          <el-button
              link
              type="primary"
              @click="openForm('update', scope.row.id)"
              v-hasPermi="['ecg:job-record:update']"
          >
            编辑
          </el-button>
          <el-button
              link
              type="danger"
              @click="handleDelete(scope.row.id)"
              v-hasPermi="['ecg:job-record:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
        :total="total"
        v-model:page="queryParams.pageNo"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />
  </ContentWrap>

</template>

<script setup lang="ts">
import { DevRentApi, DevRentVO } from '@/api/ecg/devrent'
import {dateFormatter} from "@/utils/formatTime";
import {JobRecordApi, JobRecordVO} from "@/api/ecg/jobrecord";
import {isStringEmpty} from "@/utils/stringUtil";
import {curDayEnd, curDayStart} from "@/utils/dateUtil";
import {DeviceApi} from "@/api/ecg/devmanage";
import {QueueVO} from "@/api/ecg/queue";
import {RoomBedVO} from "@/api/ecg/doctor";
import {Barcode} from "@/components/Barcode";
import {useCheckTypeStore} from "@/store/modules/checkType";
import {DICT_TYPE} from "@/utils/dict";

/** 设备装机 表单 */
defineComponent({ name: 'DevInstallPanel' })

const  props = defineProps({
  room: {
    type: Object as PropType<RoomBedVO>,
    required: true
  }
})

const emit = defineEmits(['event_dev_install']) // 定义 success 事件，用于操作成功后的回调

const checkTypeStore = useCheckTypeStore()

const setPatient = (queueVO: QueueVO | undefined) => {
  resetForm()
  formData.value.applyNo = queueVO?.applyNo
  formData.value.episodeId = queueVO?.episodeId
  formData.value.patId = queueVO?.patId
  formData.value.patName = queueVO?.patName
  formData.value.checkType = queueVO?.bookCheckType
  formData.value.patSrc = queueVO?.patDetails.source
  getReadyRentInfo(formData.value)
}
defineExpose({ setPatient }) // 提供 setPatient 方法，用于设置患者

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示

const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用

const formData = ref({})

const formRules = reactive({
  devId: [{ required: true, message: '设备编号不能为空', trigger: 'blur' }],
  rentTime: [{ required: true, message: '请选择装机日期', trigger: 'blur' }],
  patId: [{ required: true, message: '患者不能为空', trigger: 'blur' }],
  patName: [{ required: true, message: '患者名不能为空', trigger: 'blur' }]
})
const formRef = ref() // 表单 Ref

/** 提交表单 */
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    formData.value.roomId = props.room.roomId
    formData.value.bedNo = props.room.bedNo
    const data = formData.value as unknown as DevRentVO
    await DevRentApi.devInstall(data)
    message.success(t('操作成功'))
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('event_dev_install')
    resetForm()
    getList()
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    devId: undefined,
    patId: undefined,
    patName: undefined,
    patDeptCode: undefined,
    patDeptDesc: undefined,
    patWardCode: undefined,
    patWardDesc: undefined,
    patBedNo: undefined,
    rentTime: new Date().getTime(),
    returnTime: undefined,
    interference: undefined,
    baseline: undefined,
    detachment: undefined,
    remark: undefined,
    category: '',
    brand: '',
    model: '',
  }
  formRef.value?.resetFields()
}

const getDevInfo = async () => {
  if (isStringEmpty(formData.value.devId)) {
    formData.value.category = ""
    formData.value.brand = ""
    formData.value.model = ""
    return
  }

  const data = await DeviceApi.getDeviceByDevId(formData.value.devId!)
  console.info( data )
  formData.value.category = data === null ? "" : data.category
  formData.value.brand = data === null ? "" : data.brand
  formData.value.model = data === null ? "" : data.model
}

const getRentInfoByPatId = () => {
  const tempPatId = formData.value.patId;
  resetForm()
  if (isStringEmpty(tempPatId))
    return

  formData.value.patId = tempPatId;
  getReadyRentInfo(formData.value)
}

const getReadyRentInfo = async (devRentVO) => {
  const data = await DevRentApi.getReadyRent(devRentVO)
  if (null === data)
    return

  // formData.value = data  //不能整个赋值， 默认装机时间被清空
  formData.value.id = data.id;
  formData.value.applyNo = data.applyNo;
  formData.value.episodeId = data.episodeId;
  //formData.value.devId = data.devId      // 让医生手动输入，避免出错
  formData.value.category = data.category
  formData.value.brand = data.brand
  formData.value.model = data.model
  formData.value.patDetails = data.patDetails
}

const loading = ref(true) // 列表的加载中
const list = ref<JobRecordVO[]>([]) // 列表的数据
const total = ref(0) // 列表的总页数
const queryParams = reactive({
  pageNo: 1,
  pageSize: 10,
  jobType: [10, 35],
  docId: undefined,
  docName: undefined,
  devId: undefined,
  patId: undefined,
  patName: undefined,
  jobTime: [curDayStart(), curDayEnd()],
  summary: undefined,
  remark: undefined,
  createTime: []
})
/** 查询列表 */
const getList = async () => {
  loading.value = true
  try {
    const data = await JobRecordApi.getJobRecordDoctorPage(queryParams)
    list.value = data.list
    total.value = data.total
  } finally {
    loading.value = false
  }
}

const onRowClick = (cur) => {
  if (cur !== null)
    getSelectedRent( cur.rentId )
}

const getSelectedRent = async (rentId) => {
  formData.value = await DevRentApi.getDevRent(rentId)
}

const cancelInstall = async () => {
  formData.value.roomId = props.room.roomId
  formData.value.bedNo = props.room.bedNo
  const data = formData.value as unknown as DevRentVO
  if (formData.value.id === null || formData.value.id === undefined) {
    const result = await DevRentApi.devInstallCancel(data)
    formData.value.id = result
    message.success(t('操作成功'))
  } else {
    await DevRentApi.devInstallCancel(data)
    message.success(t('操作成功'))
  }
  // 发送操作成功的事件
  emit('event_dev_install')
  resetForm()
  getList()
}

const getDisplayBarcode = () => {
  if (!formData.value.checkType)
    return ""

  const displayBarcode: number[] = checkTypeStore.getCheckTypeDispBarCode(formData.value.checkType!)
  if (!displayBarcode.includes( formData.value.patSrc ))
    return ""

  if (1 === formData.value.patSrc || 2 === formData.value.patSrc)
    return formData.value.applyNo
  else if (3 === formData.value.patSrc || 4 === formData.value.patSrc)
    return formData.value.episodeId

  return ""
}

/** 初始化 **/
onMounted(() => {
  resetForm()
  getList()
})

</script>
